@@ -1,11 +1,17 @@
 # -*- coding: utf-8 -*-
 from .api.config import Config
-from .errors import APIError, ConfigurationError, ArgumentMissingError
+from .errors import (
+    APIError,
+    ConfigurationError,
+    ArgumentMissingError,
+    DeprecatedArgumentError,
+)
 
 from .api.customers.activity import CustomerActivity
 from .api.attributes import Attributes
 from .api.custom_attrs import CustomAttributes
 from .api.customer import Customer
+from .api.customer_note import CustomerNote
 from .api.contact import Contact
 from .api.data_source import DataSource
 from .api.invoice import Invoice
@@ -24,21 +30,18 @@ from .api.activities_export import ActivitiesExport
 
 from .version import __version__
 
-# Deprecated
-import imp
-
 
 """
 ChartMogul API Python Client
 
 Provides convenient Python bindings for ChartMogul's API.
 
-:copyright: (c) 2019 by ChartMogul Ltd.
+:copyright: (c) 2023 by ChartMogul Ltd.
 :license: MIT, see LICENSE for more details.
 """
 
-__title__ = 'chartmogul'
+__title__ = "chartmogul"
 __build__ = 0x000000
-__author__ = 'ChartMogul Ltd'
-__license__ = 'MIT'
-__copyright__ = 'Copyright 2021 ChartMogul Ltd'
+__author__ = "ChartMogul Ltd"
+__license__ = "MIT"
+__copyright__ = "Copyright 2023 ChartMogul Ltd"
