@@ -7,10 +7,10 @@ class Contact(Resource):
     """
     https://dev.chartmogul.com/v1.0/reference#contacts
     """
+
     _path = "/contacts{/uuid}"
     _root_key = "entries"
-    _many = namedtuple("Contacts",
-                       [_root_key, "has_more", "cursor"])
+    _many = namedtuple("Contacts", [_root_key, "has_more", "cursor"])
 
     class _Schema(Schema):
         uuid = fields.String()
