@@ -10,10 +10,10 @@ from ..resource import DataObject, Resource
 from collections import namedtuple
 from .attributes import Attributes
 from .contact import Contact
+from .customer_note import CustomerNote
 
 
 class Address(DataObject):
-
     class _Schema(Schema):
         address_zip = fields.String(allow_none=True)
         city = fields.String(allow_none=True)
@@ -29,10 +29,10 @@ class Customer(Resource):
     """
     https://dev.chartmogul.com/v1.0/reference#customers
     """
+
     _path = "/customers{/uuid}"
-    _root_key = 'entries'
-    _many = namedtuple('Customers',
-                       [_root_key, "has_more", "per_page", "page", "current_page", "total_pages"])
+    _root_key = "entries"
+    _many = namedtuple("Customers", [_root_key, "has_more", "cursor"], defaults=[None, None])
 
     class _Schema(Schema):
         # All operations
@@ -66,6 +66,7 @@ class Customer(Resource):
         currency = fields.String()
         currency_sign = fields.String(data_key="currency-sign")
         address = fields.Nested(Address._Schema, allow_none=True, unknown=EXCLUDE)
+        website_url = fields.String(allow_none=True)
 
         @post_load
         def make(self, data, **kwargs):
@@ -74,8 +75,14 @@ class Customer(Resource):
     _schema = _Schema(unknown=EXCLUDE)
 
 
-Customer.search = Customer._method('all', 'get', '/customers/search')
-Customer.merge = Customer._method('merge', 'post', '/customers/merges')
-Customer.connectSubscriptions = Customer._method('create', 'post', '/customers/{uuid}/connect_subscriptions')
-Customer.contacts = Contact._method('all', 'get', '/customers/{uuid}/contacts', useCallerClass=True)
-Customer.createContact = Contact._method('create', 'post', '/customers/{uuid}/contacts', useCallerClass=True)
+Customer.search = Customer._method("all", "get", "/customers/search")
+Customer.merge = Customer._method("merge", "post", "/customers/merges")
+Customer.connectSubscriptions = Customer._method(
+    "create", "post", "/customers/{uuid}/connect_subscriptions"
+)
+Customer.contacts = Contact._method("all", "get", "/customers/{uuid}/contacts", useCallerClass=True)
+Customer.createContact = Contact._method(
+    "create", "post", "/customers/{uuid}/contacts", useCallerClass=True
+)
+Customer.notes = CustomerNote._method("all", "get", "/customer_notes?customer_uuid={uuid}", useCallerClass=True)
+Customer.createNote = CustomerNote._method("create", "post", "/customer_notes", useCallerClass=True, useUUIDFor="customer_uuid")
