@@ -7,9 +7,10 @@ class DataSource(Resource):
     """
     https://dev.chartmogul.com/v1.0/reference#data-sources
     """
-    _path = '/data_sources{/uuid}'
-    _root_key = 'data_sources'
-    _many = namedtuple('DataSources', [_root_key])
+
+    _path = "/data_sources{/uuid}"
+    _root_key = "data_sources"
+    _many = namedtuple("DataSources", [_root_key])
 
     class _Schema(Schema):
         uuid = fields.String()
