@@ -7,9 +7,10 @@ class Plan(Resource):
     """
     https://dev.chartmogul.com/v1.0/reference#plans
     """
+
     _path = "/plans{/uuid}"
-    _root_key = 'plans'
-    _many = namedtuple('Plans', [_root_key, "current_page", "total_pages"])
+    _root_key = "plans"
+    _many = namedtuple("Plans", [_root_key, "has_more", "cursor"], defaults=[None, None])
 
     class _Schema(Schema):
         uuid = fields.String()
