@@ -5,19 +5,22 @@ from collections import namedtuple
 
 class SubscriptionEvent(Resource):
     """
-    https://dev.chartmogul.com/v1.0/reference#subscription_events
+    https://dev.chartmogul.com/reference/subscription-events
     """
+
     _path = "/subscription_events"
-    _root_key = 'subscription_events'
-    _many = namedtuple('SubscriptionEvents', [_root_key, 'meta'])
+    _root_key = "subscription_events"
+    _many = namedtuple(
+        "SubscriptionEvents", [_root_key, "has_more", "cursor"], defaults=[None, None]
+    )
 
     class _Schema(Schema):
         id = fields.Int(required=True)
         data_source_uuid = fields.String(required=True)
         customer_external_id = fields.String(required=True)
         event_type = fields.String(required=True)
-        event_date = fields.Date(required=True)
-        effective_date = fields.Date(required=True)
+        event_date = fields.DateTime(required=True)
+        effective_date = fields.DateTime(required=True)
         subscription_external_id = fields.String(allow_none=True)
         plan_external_id = fields.String(allow_none=True)
         currency = fields.String(allow_none=True)
@@ -27,6 +30,7 @@ class SubscriptionEvent(Resource):
         tax_amount_in_cents = fields.Int(allow_none=True)
         retracted_event_id = fields.String(allow_none=True)
         external_id = fields.String(allow_none=True)
+        event_order = fields.Int(allow_none=True)
 
         @post_load
         def make(self, data, **kwargs):
@@ -35,6 +39,10 @@ class SubscriptionEvent(Resource):
     _schema = _Schema(unknown=EXCLUDE)
 
 
-SubscriptionEvent.all = SubscriptionEvent._method('all', 'get', '/subscription_events')
-SubscriptionEvent.destroy_with_params = SubscriptionEvent._method('destroy_with_params', 'delete', '/subscription_events')
-SubscriptionEvent.modify_with_params = SubscriptionEvent._method('modify_with_params', 'patch', "/subscription_events")
+SubscriptionEvent.all = SubscriptionEvent._method("all", "get", "/subscription_events")
+SubscriptionEvent.destroy_with_params = SubscriptionEvent._method(
+    "destroy_with_params", "delete", "/subscription_events"
+)
+SubscriptionEvent.modify_with_params = SubscriptionEvent._method(
+    "modify_with_params", "patch", "/subscription_events"
+)
