@@ -8,6 +8,7 @@ class Tags(Resource):
     """
     https://dev.chartmogul.com/v1.0/reference#customer-attributes
     """
+
     _path = "/customers{/uuid}/attributes/tags"
 
     class _Schema(Schema):
@@ -17,7 +18,7 @@ class Tags(Resource):
         def make(self, data, **kwargs):
             return Tags(**data)
 
-    _customers = namedtuple('Customers', ['entries'])
+    _customers = namedtuple("Customers", ["entries"])
     _schema = _Schema(unknown=EXCLUDE)
 
     @classmethod
@@ -30,8 +31,8 @@ class Tags(Resource):
         if response.status_code == 204:
             return None
         jsonObj = response.json()
-        if 'entries' in jsonObj:
-            customers = Customer._schema.load(jsonObj['entries'], many=True)
+        if "entries" in jsonObj:
+            customers = Customer._schema.load(jsonObj["entries"], many=True)
             return cls._customers(customers)
         else:
             return cls._schema.load(jsonObj)
